.. _historical:

historical_inputs modules
===============================
The module provides tools for accessing historical market data and preprocessing for compatibility with the SpotMarket
class.

xml_cache
---------------

.. automodule:: nempy.historical_inputs.xml_cache
    :autosummary:
    :members:
    :inherited-members:
    :exclude-members: timedelta,datetime,time,Path,xmltodict

mms_db
-----------------------------------------

.. automodule:: nempy.historical_inputs.mms_db
    :autosummary:
    :members:
    :inherited-members:
    :exclude-members: timedelta,datetime

loaders
-----------------------------------------

.. automodule:: nempy.historical_inputs.loaders
    :autosummary:
    :members:

units
--------

.. automodule:: nempy.historical_inputs.units
    :autosummary:
    :members:

interconnectors
------------------

.. automodule:: nempy.historical_inputs.interconnectors
    :autosummary:
    :members:

demand
------------------

.. automodule:: nempy.historical_inputs.demand
    :autosummary:
    :members:

constraints
------------------

.. automodule:: nempy.historical_inputs.constraints
    :autosummary:
    :members:


